var {
  useFocus,
  useHover
} = require("@react-ui-aria/interactions");

var {
  chain,
  filterDOMProps,
  mergeProps
} = require("@react-ui-aria/utils");

var _babelRuntimeHelpersExtends = $parcel$interopDefault(require("@babel/runtime/helpers/extends"));

function $parcel$interopDefault(a) {
  return a && a.__esModule ? a.default : a;
}

function useToast(props, state) {
  let {
    toastKey,
    onAction,
    onClose,
    shouldCloseOnAction,
    timer,
    variant
  } = props;
  let {
    onRemove
  } = state;
  let domProps = filterDOMProps(props);

  const handleAction = function handleAction() {
    if (onAction) {
      onAction(...arguments);
    }

    if (shouldCloseOnAction) {
      onClose && onClose(...arguments);
      onRemove && onRemove(toastKey);
    }
  };

  let iconProps = variant ? {
    'aria-label': variant
  } : {};

  let pauseTimer = () => {
    timer && timer.pause();
  };

  let resumeTimer = () => {
    timer && timer.resume();
  };

  let {
    hoverProps
  } = useHover({
    onHoverStart: pauseTimer,
    onHoverEnd: resumeTimer
  });
  let {
    focusProps
  } = useFocus({
    onFocus: pauseTimer,
    onBlur: resumeTimer
  });
  return {
    toastProps: mergeProps(domProps, _babelRuntimeHelpersExtends({}, hoverProps, {
      role: 'alert'
    })),
    iconProps,
    actionButtonProps: _babelRuntimeHelpersExtends({}, focusProps, {
      onPress: handleAction
    }),
    closeButtonProps: _babelRuntimeHelpersExtends({
      'aria-label': 'close'
    }, focusProps, {
      onPress: chain(onClose, () => onRemove(toastKey))
    })
  };
}

exports.useToast = useToast;
//# sourceMappingURL=main.js.map
