import { useFocus, useHover } from "@react-ui-aria/interactions";
import { chain, filterDOMProps, mergeProps } from "@react-ui-aria/utils";
import _babelRuntimeHelpersEsmExtends from "@babel/runtime/helpers/esm/extends";
export function useToast(props, state) {
  let {
    toastKey,
    onAction,
    onClose,
    shouldCloseOnAction,
    timer,
    variant
  } = props;
  let {
    onRemove
  } = state;
  let domProps = filterDOMProps(props);

  const handleAction = function handleAction() {
    if (onAction) {
      onAction(...arguments);
    }

    if (shouldCloseOnAction) {
      onClose && onClose(...arguments);
      onRemove && onRemove(toastKey);
    }
  };

  let iconProps = variant ? {
    'aria-label': variant
  } : {};

  let pauseTimer = () => {
    timer && timer.pause();
  };

  let resumeTimer = () => {
    timer && timer.resume();
  };

  let {
    hoverProps
  } = useHover({
    onHoverStart: pauseTimer,
    onHoverEnd: resumeTimer
  });
  let {
    focusProps
  } = useFocus({
    onFocus: pauseTimer,
    onBlur: resumeTimer
  });
  return {
    toastProps: mergeProps(domProps, _babelRuntimeHelpersEsmExtends({}, hoverProps, {
      role: 'alert'
    })),
    iconProps,
    actionButtonProps: _babelRuntimeHelpersEsmExtends({}, focusProps, {
      onPress: handleAction
    }),
    closeButtonProps: _babelRuntimeHelpersEsmExtends({
      'aria-label': 'close'
    }, focusProps, {
      onPress: chain(onClose, () => onRemove(toastKey))
    })
  };
}
//# sourceMappingURL=module.js.map
